@@ -16,7 +16,6 @@ import (
 	"golang.org/x/sys/windows"
 
 	"golang.zx2c4.com/wireguard/tun/wintun/memmod"
-	"golang.zx2c4.com/wireguard/tun/wintun/resource"
 )
 
 type lazyDLL struct {
@@ -37,11 +36,11 @@ func (d *lazyDLL) Load() error {
 	}
 
 	const ourModule windows.Handle = 0
-	resInfo, err := resource.FindByName(ourModule, d.Name, resource.RT_RCDATA)
+	resInfo, err := windows.FindResource(ourModule, d.Name, windows.RT_RCDATA)
 	if err != nil {
 		return fmt.Errorf("Unable to find \"%v\" RCDATA resource: %w", d.Name, err)
 	}
-	data, err := resource.Load(ourModule, resInfo)
+	data, err := windows.LoadResourceData(ourModule, resInfo)
 	if err != nil {
 		return fmt.Errorf("Unable to load resource: %w", err)
 	}
